[jboss-remoting-commits] JBoss Remoting SVN: r5305 - remoting2/branches/2.2/src/main/org/jboss/remoting/transport/bisocket.

jboss-remoting-commits at lists.jboss.org jboss-remoting-commits at lists.jboss.org
Tue Jul 7 21:53:38 EDT 2009


Author: david.lloyd at jboss.com
Date: 2009-07-07 21:53:38 -0400 (Tue, 07 Jul 2009)
New Revision: 5305

Modified:
   remoting2/branches/2.2/src/main/org/jboss/remoting/transport/bisocket/BisocketClientInvoker.java
   remoting2/branches/2.2/src/main/org/jboss/remoting/transport/bisocket/BisocketServerInvoker.java
Log:
Make the JBREM-1140 change safe for 1.4 - just in case

Modified: remoting2/branches/2.2/src/main/org/jboss/remoting/transport/bisocket/BisocketClientInvoker.java
===================================================================
--- remoting2/branches/2.2/src/main/org/jboss/remoting/transport/bisocket/BisocketClientInvoker.java	2009-07-08 00:09:13 UTC (rev 5304)
+++ remoting2/branches/2.2/src/main/org/jboss/remoting/transport/bisocket/BisocketClientInvoker.java	2009-07-08 01:53:38 UTC (rev 5305)
@@ -207,8 +207,8 @@
          val = configuration.get(Bisocket.ENABLE_PING_REPLIES);
          if (val != null)
          {
-            // parseBoolean doesn't throw exceptions :-)
-            boolean bVal = Boolean.parseBoolean((String) val);
+            // Boolean.valueOf doesn't throw exceptions :-)
+            boolean bVal = Boolean.valueOf((String) val).booleanValue();
             enablePingReplies = bVal;
          }
       }

Modified: remoting2/branches/2.2/src/main/org/jboss/remoting/transport/bisocket/BisocketServerInvoker.java
===================================================================
--- remoting2/branches/2.2/src/main/org/jboss/remoting/transport/bisocket/BisocketServerInvoker.java	2009-07-08 00:09:13 UTC (rev 5304)
+++ remoting2/branches/2.2/src/main/org/jboss/remoting/transport/bisocket/BisocketServerInvoker.java	2009-07-08 01:53:38 UTC (rev 5305)
@@ -206,8 +206,8 @@
       Object val = configuration.get(Bisocket.ENABLE_PING_REPLIES);
       if (val != null)
       {
-         // parseBoolean doesn't throw exceptions :-)
-         boolean bVal = Boolean.parseBoolean((String) val);
+         // Boolean.valueOf doesn't throw exceptions :-)
+         boolean bVal = Boolean.valueOf((String) val).booleanValue();
          enablePingReplies = bVal;
       }
    }




More information about the jboss-remoting-commits mailing list